package jp.co.sds_corp.syslog;

import java.net.DatagramPacket;
import java.net.DatagramSocket;
import java.net.InetAddress;

import jp.co.sds_corp.util.syslog.SyslogMsg;

/**
* syslogを送信するテスト用のクラスです。
*/
public class SyslogSend {
	DatagramSocket socWrite=null;
	int port=514;
	InetAddress addrWrite=null;

	public SyslogSend( String host ) {
		this( host, 514 );
	}

	public SyslogSend( String host, int port ) {
		System.out.println( "send: " + host + ":" + port );
		this.port = port;
		try{
			socWrite=new DatagramSocket();
			if ( host.length() == 0 ) {
				addrWrite=InetAddress.getLocalHost();
			} else {
				addrWrite=InetAddress.getByName( host );
			}
		} catch ( Exception ex ) {
			ex.printStackTrace();
		}
	}

	public void send( String facility, String priority, String msg, String times )
		throws Exception
	{
		try{
			int nTimes = Integer.valueOf( times ).intValue();
			for ( int i = 0; i < nTimes; i++ ) {
				send( facility, priority, msg );
			}
		} catch ( Exception ex ) {
			ex.printStackTrace();
		}
	}

	public void send( String facility, String priority, String msg )
		throws Exception
	{
		SyslogMsg	log = new SyslogMsg( facility, priority, msg );
		String	str = log.getData();
System.out.println( str );
		try{
			byte[] byteWrite = str.getBytes();
			DatagramPacket packet=new DatagramPacket(byteWrite,byteWrite.length,addrWrite,port);
			socWrite.send( packet );
		} catch ( Exception ex ) {
			ex.printStackTrace();
		}
	}

	public void close()	{
		if ( socWrite != null ) {
			socWrite.close();
			socWrite = null;
		}
	}

	public static void usage() {
		System.err.println( "usage: java SyslogSend <host> <facility> <priority> <msg> {times}" );
		System.exit( 9 );
	}

	public static void main( String[] args ) {
		if ( args.length != 4 && args.length != 5 ) {
			usage();
		}
		try {
			String port = System.getProperty( "syslog.port" );
			SyslogSend	obj;
			if ( port == null ) {
				obj = new SyslogSend( args[0] );
			} else {
				obj = new SyslogSend( args[0], Integer.valueOf( port ).intValue() );
			}
			if ( args.length == 4 ) {
				obj.send( args[1], args[2], args[3] );
			} else {
				obj.send( args[1], args[2], args[3], args[4] );
			}
			obj.close();
		} catch ( Exception ex ) {
			ex.printStackTrace();
		}

		System.exit( 0 );
	}
}
