package	jp.co.sds_corp.syslog.viewer;

import java.awt.Window;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.net.InetAddress;
import java.util.ResourceBundle;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JPanel;

import jp.co.sds_corp.syslog.layout.ILayout;
import jp.co.sds_corp.syslog.layout.SyslogLayout;
import jp.co.sds_corp.util.common.CmnDate;
import jp.co.sds_corp.util.syslog.Facility;
import jp.co.sds_corp.util.syslog.Priority;
import jp.co.sds_corp.util.syslog.SyslogMsg;
import jp.co.sds_corp.util.window.ValuePanel;

/**
* {@link ILayout}を設定するパネルです。
*/
public class LayoutPanel extends JPanel
{
	private static final long serialVersionUID = 1L;
	Window		owner;
	SyslogParam	param;
	ILayout		layout;
	SyslogLayout	sampleLayout;
	ValuePanel	PNL_FMT;
	JButton		BTN_TEST;
	SyslogMsg	sample;
	ResourceBundle res;

	public LayoutPanel( JDialog owner, SyslogParam param ) {
		this.owner = owner;
		this.param = param;
		createControls();
	}

	public LayoutPanel( JFrame owner, SyslogParam param ) {
		this.owner = owner;
		this.param = param;
		createControls();
	}

	protected void createControls() {
		res = ResourceBundle.getBundle( "resource.viewer" );
		sampleLayout = new SyslogLayout();
		sample = new SyslogMsg( Facility.USER, Priority.ERR,
			"sample message" );
		sample.setDate( new CmnDate() );
		try {
			sample.setAddress( InetAddress.getLocalHost() );
		} catch ( Exception e ) {
		}

		PNL_FMT = new ValuePanel( ValuePanel.ReturnType.STRING, "Format" );
		add( PNL_FMT );

		String text;
		text = res.getString( "layout.test.text" );
		BTN_TEST = new JButton( text );
		BTN_TEST.setMnemonic( KeyEvent.VK_T );
		add( BTN_TEST );
		BTN_TEST.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent e ) {
				onTest();
			}
		});
	}

	private void onTest() {
		String fmt = (String )PNL_FMT.getValue();
		if ( fmt.length() == 0 ) {
			return;
		}
		sampleLayout.setFormat( fmt );
		String res = sampleLayout.format( sample );
		String title = this.res.getString( "layout.test.title" );
		JOptionPane.showMessageDialog( getParent(),
			res, title,
			JOptionPane.INFORMATION_MESSAGE);
	}

	/**
	* {@link ILayout}を入力された情報で更新します。
	*/
	public void updateLayout() {
		if ( layout != null ) {
			layout.setFormat( (String )PNL_FMT.getValue() );
		}
	}

	/**
	* syslogをフォーマットするILayout(layout)を設定します。
	* @param	var		設定するデータ
	*/
	public void setSyslogLayout( ILayout var ) {
		this.layout = var ;
		if ( layout == null ) {
			PNL_FMT.setValue( null );
			layout = new SyslogLayout();
		} else {
			PNL_FMT.setValue( layout.getFormat() );
		}
	}
	/**
	* syslogをフォーマットするILayout(layout)を取得します。
	* @return	layoutの内容
	*/
	public ILayout getSyslogLayout() {
		if ( ((String )PNL_FMT.getValue()).length() == 0 ) {
			return null;
		}
		return layout;
	}

}
