package	jp.co.sds_corp.syslog.filter;

import jp.co.sds_corp.util.config.IConfiguration;

/**
* syslogのフィルタリングを行なうクラスの基底クラスです。
*/
public abstract class AbstractFilter implements IFilter
{
	private static final long serialVersionUID = 1L;
	boolean	valid = true;
	boolean	exclude = false;

	/**
	* 指定された初期情報で初期化します。
	* @param    config  初期情報
	*/
	public void init( IConfiguration config ) throws Exception {
		exclude = config.getBoolean( "Exclude", false );
		valid = config.getBoolean( "Valid", true );
	}

	/**
	* このフィルタの条件が排他であるかどうかを返します。
	*/
	public boolean isExclude() {
		return exclude;
	}

	/**
	* このフィルタの排他条件を設定します。
	* @param	var		排他条件
	*/
	public void setExclude( boolean var ) {
		this.exclude = var;
	}

	/**
	* このフィルタが有効であるかどうかを返します。
	*/
	public boolean isValid() {
		return valid;
	}

	/**
	* このフィルタの有効であるかどうかを設定します。
	* @param	var		有効フラグ
	*/
	public void setValid( boolean var ) {
		this.valid = var;
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	親ノード
	*/
	public void saveConfig( IConfiguration config ) {
		config.setAttribute( "class", getClass().getName() );
		if ( isExclude()) {
			config.addChild( "Exclude", "true" );
		}
		if ( !isValid()) {
			config.addChild( "Valid", "false" );
		}
	}

	/**
	* 設定内容の文字列表現を返します。
	*/
	public String paramString() {
		String ret = "";
		if ( !isValid()) {
			ret += "X ";
		}
		if ( isExclude()) {
			ret += "EXC ";
		}
		return ret;
	}

	/**
	* このフィルタの文字列表現を返します。
	*/
	public String toString() {
		String ret = getClass().getName();
		ret += paramString();
		return ret;
	}

}
